AlternateName

Struct AlternateName 

pub struct AlternateName {
    pub alternate_name_id: i32,
    pub geo_name_id: i32,
    pub isolanguage: Option<String>,
    pub alternate_name: String,
    pub is_preferred_name: bool,
    pub is_short_name: bool,
    pub is_colloquial: bool,
    pub is_historic: bool,
}

Fields

alternate_name_id: i32

the id of this alternate name, int

geo_name_id: i32

geonameId referring to id in table ‘geoname’, int

isolanguage: Option<String>

iso 639 language code 2- or 3-characters; 4-characters ‘post’ for postal codes and ‘iata’,‘icao’ and faac for airport codes, fr_1793 for French Revolution names, abbr for abbreviation, link to a website (mostly to wikipedia), wkdt for the wikidataid, varchar(7)

alternate_name: String

alternate name or name variant, varchar(400)

is_preferred_name: bool

‘1’, if this alternate name is an official/preferred name

is_short_name: bool

‘1’, if this is a short name like ‘California’ for ‘State of California’

is_colloquial: bool

‘1’, if this alternate name is a colloquial or slang term. Example: ‘Big Apple’ for ‘New York’.

is_historic: bool

‘1’, if this alternate name is historic and was used in the past. Example ‘Bombay’ for ‘Mumbai’.

Implementations

Source

impl AlternateName

pub fn deserialize_from_string(str: &str) -> Result<Self, DeserializeErr>

Receive string example

1554355	5128581	en	Big Apple			1
Examples found in repository?
examples/simple.rs (line 16)
6fn main() {
7    for (index, line) in BufReader::new(File::open("./test-data/admin1CodesASCII.txt").unwrap()).lines().enumerate() {
8        let admin_code = AdminCode::deserialize_from_string(&line.unwrap()).unwrap();
9        println!("{:#?}", admin_code);
10        if index > 20 {
11            break;
12        }
13    }
14
15    for (index, line) in BufReader::new(File::open("./test-data/alternate_name_gb.txt").unwrap()).lines().enumerate() {
16        let alternate_name = AlternateName::deserialize_from_string(&line.unwrap()).unwrap();
17        println!("{:#?}", alternate_name);
18        if index > 20 {
19            break;
20        }
21    }
22
23    for (index, line) in BufReader::new(File::open("./test-data/geonames_gb.txt").unwrap()).lines().enumerate() {
24        let geo_name = GeoName::deserialize_from_string(&line.unwrap()).unwrap();
25        println!("{:#?}", geo_name);
26        if index > 20 {
27            break;
28        }
29    }
30}