[−][src]Struct geonames_lib::model::GeoName
Соответствие типов полей было проверенно на базе 05.05.2020
Fields
geonameid: i32integer id of record in geonames database
name: Stringname of geographical point (utf8) varchar(200)
asciiname: Option<String>name of geographical point in plain ascii characters, varchar(200)
alternatenames: Vec<String>alternatenames, comma separated, ascii names automatically transliterated, convenience attribute from alternatename table, varchar(10000)
latitude: Decimallatitude in decimal degrees (wgs84)
longitude: Decimallongitude in decimal degrees (wgs84)
feature_class: Option<String>see http://www.geonames.org/export/codes.html, char(1)
feature_code: Option<String>see http://www.geonames.org/export/codes.html, varchar(10)
country_code: Option<String>ISO-3166 2-letter country code, 2 characters
cc2: Option<String>alternate country codes, comma separated, ISO-3166 2-letter country code, 200 characters
admin1_code: Option<String>fipscode (subject to change to iso code), see exceptions below, see file admin1Codes.txt for display names of this code; varchar(20)
admin2_code: Option<String>code for the second administrative division, a county in the US, see file admin2Codes.txt; varchar(80)
admin3_code: Option<String>code for third level administrative division, varchar(20)
admin4_code: Option<String>code for fourth level administrative division, varchar(20)
population: Option<i64>bigint (8 byte int)
elevation: Option<i32>in meters, integer
dem: Stringdigital elevation model, srtm3 or gtopo30, average elevation of 3''x3'' (ca 90mx90m) or 30''x30'' (ca 900mx900m) area in meters, integer. srtm processed by cgiar/ciat.
timezone: Option<String>the iana timezone id (see file timeZone.txt) varchar(40)
modification: DateTime<Utc>date of last modification in yyyy-MM-dd format
Implementations
impl GeoName[src]
pub fn deserialize_from_string(str: &str) -> Result<Self, DeserializeErr>[src]
Receive string example
1485680 Yurty Yurty Jurty,Yurty,Юрты 56.0498 97.6348 P PPL RU 20 5902 301 Asia/Irkutsk 2012-01-17